==> haskell-mwc-random-0.15.1.0-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mwc-random
version:              0.15.1.0
visibility:           public
id:                   mwc-random-0.15.1.0-L7uo6hvot2QA4Ry7jntvwx
key:                  mwc-random-0.15.1.0-L7uo6hvot2QA4Ry7jntvwx
license:              BSD-2-Clause
copyright:            2009, 2010, 2011 Bryan O'\''Sullivan
maintainer:           Alexey Khudyakov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/mwc-random
synopsis:             Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.

category:             Math, Statistics
abi:                  02a34c8b0318624d8edf07e17a9bbd00
exposed:              True
exposed-modules:
    System.Random.MWC System.Random.MWC.CondensedTable
    System.Random.MWC.Distributions System.Random.MWC.SeedSource

import-dirs:          /usr/lib/ghc-9.2.8/site-local/mwc-random-0.15.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mwc-random-0.15.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mwc-random
hs-libraries:         HSmwc-random-0.15.1.0-L7uo6hvot2QA4Ry7jntvwx
depends:
    base-4.16.4.0 math-functions-0.3.4.4-bJIbxJm3ZnEvmNU4NREUw
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh time-1.11.1.1
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html:         /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mwc-random-0.15.2.0-18.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mwc-random
version:              0.15.2.0
visibility:           public
id:                   mwc-random-0.15.2.0-LGDu0vyCwvJvMM0yIrRXu
key:                  mwc-random-0.15.2.0-LGDu0vyCwvJvMM0yIrRXu
license:              BSD-2-Clause
copyright:            2009, 2010, 2011 Bryan O'\''Sullivan
maintainer:           Alexey Khudyakov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/mwc-random
synopsis:             Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.

category:             Math, Statistics
abi:                  e88b53d2f6e357718415b981912cfa5b
exposed:              True
exposed-modules:
    System.Random.MWC System.Random.MWC.CondensedTable
    System.Random.MWC.Distributions System.Random.MWC.SeedSource

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mwc-random-0.15.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mwc-random-0.15.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mwc-random-0.15.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mwc-random
hs-libraries:         HSmwc-random-0.15.2.0-LGDu0vyCwvJvMM0yIrRXu
depends:
    base-4.17.2.1 math-functions-0.3.4.4-4vzWv2sXN6p2reAyiwlsZN
    primitive-0.8.0.0-RoAiLvCruBL00EsvIFp5f
    random-1.2.1.2-5Y3bNr2vhgE1UbXPPVLWyj time-1.12.2
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16

haddock-interfaces:   /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html:         /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
